@@ -20,23 +20,32 @@ func (r Nagios) ValidOptions() []*formatOption {
 }
 
 func (r Nagios) Output(w io.Writer, results <-chan []resource.TestResult,
-	startTime time.Time, outConfig util.OutputConfig) (exitCode int) {
+	outConfig util.OutputConfig) (exitCode int) {
 
 	var testCount, failed, skipped int
 
 	var perfdata, verbose bool
 	perfdata = util.IsValueInList(foPerfData, outConfig.FormatOptions)
 	verbose = util.IsValueInList(foVerbose, outConfig.FormatOptions)
+	includeRaw := !util.IsValueInList(foExcludeRaw, outConfig.FormatOptions)
 
+	var startTime time.Time
+	var endTime time.Time
 	var summary map[int]string
 	summary = make(map[int]string)
 
 	for resultGroup := range results {
 		for _, testResult := range resultGroup {
+			if startTime.IsZero() || testResult.StartTime.Before(startTime) {
+				startTime = testResult.StartTime
+			}
+			if endTime.IsZero() || testResult.EndTime.After(endTime) {
+				endTime = testResult.EndTime
+			}
 			switch testResult.Result {
 			case resource.FAIL:
 				if util.IsValueInList(foVerbose, outConfig.FormatOptions) {
-					summary[failed] = "Fail " + strconv.Itoa(failed+1) + " - " + humanizeResult2(testResult) + "\n"
+					summary[failed] = "Fail " + strconv.Itoa(failed+1) + " - " + humanizeResult(testResult, true, includeRaw) + "\n"
 				}
 				failed++
 			case resource.SKIP:
@@ -46,7 +55,7 @@ func (r Nagios) Output(w io.Writer, results <-chan []resource.TestResult,
 		}
 	}
 
-	duration := time.Since(startTime)
+	duration := endTime.Sub(startTime)
 	if failed > 0 {
 		fmt.Fprintf(w, "GOSS CRITICAL - Count: %d, Failed: %d, Skipped: %d, Duration: %.3fs", testCount, failed, skipped, duration.Seconds())
 		if perfdata {
