@@ -1,6 +1,8 @@
 package resource
 
 import (
+	"context"
+	"fmt"
 	"time"
 
 	"github.com/goss-org/goss/system"
@@ -10,7 +12,8 @@ import (
 type Addr struct {
 	Title        string  `json:"title,omitempty" yaml:"title,omitempty"`
 	Meta         meta    `json:"meta,omitempty" yaml:"meta,omitempty"`
-	Address      string  `json:"-" yaml:"-"`
+	id           string  `json:"-" yaml:"-"`
+	Address      string  `json:"address,omitempty" yaml:"address,omitempty"`
 	LocalAddress string  `json:"local-address,omitempty" yaml:"local-address,omitempty"`
 	Reachable    matcher `json:"reachable" yaml:"reachable"`
 	Timeout      int     `json:"timeout" yaml:"timeout"`
@@ -26,8 +29,13 @@ func init() {
 	registerResource(AddrResourceKey, &Addr{})
 }
 
-func (a *Addr) ID() string       { return a.Address }
-func (a *Addr) SetID(id string)  { a.Address = id }
+func (a *Addr) ID() string {
+	if a.Address != "" && a.Address != a.id {
+		return fmt.Sprintf("%s: %s", a.id, a.Address)
+	}
+	return a.id
+}
+func (a *Addr) SetID(id string)  { a.id = id }
 func (a *Addr) SetSkip()         { a.Skip = true }
 func (a *Addr) TypeKey() string  { return AddrResourceKey }
 func (a *Addr) TypeName() string { return AddResourceName }
@@ -35,15 +43,22 @@ func (a *Addr) TypeName() string { return AddResourceName }
 // FIXME: Can this be refactored?
 func (a *Addr) GetTitle() string { return a.Title }
 func (a *Addr) GetMeta() meta    { return a.Meta }
+func (a *Addr) GetAddress() string {
+	if a.Address != "" {
+		return a.Address
+	}
+	return a.id
+}
 
 func (a *Addr) Validate(sys *system.System) []TestResult {
+	ctx := context.WithValue(context.Background(), "id", a.ID())
 	skip := a.Skip
 
 	if a.Timeout == 0 {
 		a.Timeout = 500
 	}
 
-	sysAddr := sys.NewAddr(a.Address, sys, util.Config{Timeout: time.Duration(a.Timeout) * time.Millisecond, LocalAddress: a.LocalAddress})
+	sysAddr := sys.NewAddr(ctx, a.GetAddress(), sys, util.Config{Timeout: time.Duration(a.Timeout) * time.Millisecond, LocalAddress: a.LocalAddress})
 
 	var results []TestResult
 	results = append(results, ValidateValue(a, "reachable", a.Reachable, sysAddr.Reachable, skip))
@@ -54,7 +69,7 @@ func NewAddr(sysAddr system.Addr, config util.Config) (*Addr, error) {
 	address := sysAddr.Address()
 	reachable, err := sysAddr.Reachable()
 	a := &Addr{
-		Address:      address,
+		id:           address,
 		Reachable:    reachable,
 		Timeout:      config.TimeOutMilliSeconds(),
 		LocalAddress: config.LocalAddress,
