@@ -18,7 +18,9 @@ type File struct {
 	Mode     matcher `json:"mode,omitempty" yaml:"mode,omitempty"`
 	Size     matcher `json:"size,omitempty" yaml:"size,omitempty"`
 	Owner    matcher `json:"owner,omitempty" yaml:"owner,omitempty"`
+	Uid      matcher `json:"uid,omitempty" yaml:"uid,omitempty"`
 	Group    matcher `json:"group,omitempty" yaml:"group,omitempty"`
+	Gid      matcher `json:"gid,omitempty" yaml:"gid,omitempty"`
 	LinkedTo matcher `json:"linked-to,omitempty" yaml:"linked-to,omitempty"`
 	Filetype matcher `json:"filetype,omitempty" yaml:"filetype,omitempty"`
 	Contains matcher `json:"contains,omitempty" yaml:"contains,omitempty"`
@@ -74,9 +76,15 @@ func (f *File) Validate(sys *system.System) []TestResult {
 	if f.Owner != nil {
 		results = append(results, ValidateValue(f, "owner", f.Owner, sysFile.Owner, skip))
 	}
+	if f.Uid != nil {
+		results = append(results, ValidateValue(f, "uid", f.Uid, sysFile.Uid, skip))
+	}
 	if f.Group != nil {
 		results = append(results, ValidateValue(f, "group", f.Group, sysFile.Group, skip))
 	}
+	if f.Gid != nil {
+		results = append(results, ValidateValue(f, "gid", f.Gid, sysFile.Gid, skip))
+	}
 	if f.LinkedTo != nil {
 		results = append(results, ValidateValue(f, "linkedto", f.LinkedTo, sysFile.LinkedTo, skip))
 	}
