@@ -1,6 +1,9 @@
 package resource
 
 import (
+	"context"
+	"fmt"
+
 	"github.com/goss-org/goss/system"
 	"github.com/goss-org/goss/util"
 )
@@ -8,7 +11,8 @@ import (
 type Port struct {
 	Title     string  `json:"title,omitempty" yaml:"title,omitempty"`
 	Meta      meta    `json:"meta,omitempty" yaml:"meta,omitempty"`
-	Port      string  `json:"-" yaml:"-"`
+	id        string  `json:"-" yaml:"-"`
+	Port      string  `json:"port,omitempty" yaml:"port,omitempty"`
 	Listening matcher `json:"listening" yaml:"listening"`
 	IP        matcher `json:"ip,omitempty" yaml:"ip,omitempty"`
 	Skip      bool    `json:"skip,omitempty" yaml:"skip,omitempty"`
@@ -23,17 +27,29 @@ func init() {
 	registerResource(PortResourceKey, &Port{})
 }
 
-func (p *Port) ID() string       { return p.Port }
-func (p *Port) SetID(id string)  { p.Port = id }
+func (p *Port) ID() string {
+	if p.Port != "" && p.Port != p.id {
+		return fmt.Sprintf("%s: %s", p.id, p.Port)
+	}
+	return p.id
+}
+func (p *Port) SetID(id string)  { p.id = id }
 func (p *Port) SetSkip()         { p.Skip = true }
 func (p *Port) TypeKey() string  { return PortResourceKey }
 func (p *Port) TypeName() string { return PortResourceName }
 func (p *Port) GetTitle() string { return p.Title }
 func (p *Port) GetMeta() meta    { return p.Meta }
+func (p *Port) GetPort() string {
+	if p.Port != "" {
+		return p.Port
+	}
+	return p.id
+}
 
 func (p *Port) Validate(sys *system.System) []TestResult {
+	ctx := context.WithValue(context.Background(), "id", p.ID())
 	skip := p.Skip
-	sysPort := sys.NewPort(p.Port, sys, util.Config{})
+	sysPort := sys.NewPort(ctx, p.GetPort(), sys, util.Config{})
 
 	var results []TestResult
 	results = append(results, ValidateValue(p, "listening", p.Listening, sysPort.Listening, skip))
@@ -50,7 +66,7 @@ func NewPort(sysPort system.Port, config util.Config) (*Port, error) {
 	port := sysPort.Port()
 	listening, _ := sysPort.Listening()
 	p := &Port{
-		Port:      port,
+		id:        port,
 		Listening: listening,
 	}
 	if !contains(config.IgnoreList, "ip") {
