@@ -25,7 +25,9 @@ type File interface {
 	Size() (int, error)
 	Filetype() (string, error)
 	Owner() (string, error)
+	Uid() (int, error)
 	Group() (string, error)
+	Gid() (int, error)
 	LinkedTo() (string, error)
 	Md5() (string, error)
 	Sha256() (string, error)
